clear all
clc

% This example illustrates how to apply the VARDAS model when
% some variables changes frequency from low to high at a given time.

% Set parameters of VAR model
nobs = 3000;
Tc = nobs * 0.5;
dim = 2;
nlag = 1;
nagg = 3;
sum_flag = 0;
ndraws = 3000;
burn_in = ndraws * 0.5;
add_constant = 1;
cov_true = 0.7 * eye(dim) + 0.3 * ones(dim,dim);

Phi_true = zeros(dim,dim,nlag);
for p = 1:nlag
    Phi_true(:,:,p) = (ones(dim,dim) * 0.25/dim + eye(dim,dim) * 0.25/dim) / 2^(p-1);
    disp(['True Phi(',num2str(p),')'])
    disp(Phi_true(:,:,p))
end

const_true = ones(dim,1);
mat_temp = eye(dim,dim);
for p = 1:nlag
    mat_temp = mat_temp - Phi_true(:,:,p);
end
mean_true = mat_temp \ const_true;

% Simulate data of VAR
nobs = ceil(nobs / nagg) * nagg;
Y = zeros(dim,nobs);
Y(:,1:nlag) = mean_true(:,ones(nlag,1));
for t = nlag + 1 : nobs
    Y(:,t) = const_true + chol(cov_true)' * randn(dim,1);
    for p = 1:nlag
        Y(:,t) = Y(:,t) + Phi_true(:,:,p) * Y(:,t-p);
    end    
end
Y_full = Y;

% Aggregate data
for t = nagg:nagg:Tc
    if sum_flag == 1
        Y(2:end, t) = sum(Y(2:end,t-nagg+1:t),2);
    else
        Y(2:end, t) = mean(Y(2:end,t-nagg+1:t),2);
    end
    Y(2:end, t-nagg+1:t-1) = NaN;
end


disp('----------')
disp('VARDAS 2: Frequency change once')
disp('----------')
[Phi_draws2, Sigma_draws2,constant_draws2] = VARDAS2(Y,nlag,sum_flag,add_constant,ndraws,burn_in);

return

disp('----------')
disp('VARDAS 3: Designated blocks')
disp('----------')
block = nagg * 2;
[Phi_draws3, Sigma_draws3,constant_draws3] = VARDAS3(Y,nlag,sum_flag,block,add_constant,1000)

disp('----------')
disp('VARDAS 4: VARDAS WHOLE')
disp('----------')
block = nagg * 2;
[Phi_draws4, Sigma_draws4,constant_draws4] = VARDAS4(Y,nlag,sum_flag,add_constant,300);

disp('----------')
disp('LATENT VAR')
disp('----------')
[Phi_draws,Sigma_draws] = GIBBS_VAR(Y_full',nlag,ndraws,burn_in,add_constant);