clear all
clc

% This example illustrates how to apply the VARDAS model when
% some differenced variables are observed at low frequency 
% while other variables at high frequency

% Set parameters of VAR model
nobs = 1500;
J = 3;
sum_flag = 0;
dim = 2;
nlag = 1;
ndraws = 5000;
burn_in = ndraws * 0.5;
add_constant = 1;
cov_true = 0.7 * eye(dim) + 0.3 * ones(dim,dim);

Phi_true = zeros(dim,dim,nlag);
for p = 1:nlag
    Phi_true(:,:,p) = (ones(dim,dim) * 0.25/dim + eye(dim,dim) * 0.25/dim) / 2^(p-1);
    disp(['True Phi(',num2str(p),')'])
    disp(Phi_true(:,:,p))
end

const_true = ones(dim,1);
mat_temp = eye(dim,dim);
for p = 1:nlag
    mat_temp = mat_temp - Phi_true(:,:,p);
end
mean_true = mat_temp \ const_true;

% Simulate data of VAR
nobs = ceil(nobs / J) * J;
nextra = max(J,nlag);
Y = zeros(dim,nobs+nextra);
Y(:,1:nextra) = mean_true(:,ones(nextra,1));
for t = nextra + 1 : nobs+nextra
    Y(:,t) = const_true + chol(cov_true)' * randn(dim,1);
    for p = 1:nlag
        Y(:,t) = Y(:,t) + Phi_true(:,:,p) * Y(:,t-p);
    end    
end
Y_full = Y(:,nextra+1:end);

% Aggregate data
Y1_level = cumsum(Y(1,:));
Y1 = NaN(1,nobs+nextra);
for t = 2*J:J:nobs+nextra
    if sum_flag == 1
        Y1(t) = sum(Y1_level(t-J+1:t)) - sum(Y1_level(t-2*J+1:t-J));
    else
        Y1(t) = mean(Y1_level(t-J+1:t)) - mean(Y1_level(t-2*J+1:t-J));
    end    
end
Y(1,:) = Y1;
Y = Y(:,nextra+1:end);


% Estimate the model
disp('----------')
disp('VARDAS DIFF')
disp('----------')
[Phi_draws, Sigma_draws,constant_draws] = VARDAS_DIFF1(Y,nlag,sum_flag,add_constant,ndraws,burn_in);

disp('----------')
disp('LATENT VAR')
disp('----------')
[Phi_draws,Sigma_draws] = GIBBS_VAR(Y_full',nlag,ndraws,burn_in,add_constant);