
% This is a graphic interface for Bayesian VAR with varied frequency data
% Prepare your data in a EXCEL file.
% Follow instruction on screen, you can estimate the model by clicking the mouse.
% If you do not need graphic interface, you can directly call the Matlab functions
% VARDAS1(Y,nlag,sum_flag,add_constant,ndraws,burn_in)
% VARDAS2(Y,nlag,sum_flag,block,add_constant,ndraws,burn_in)
% VARDAS3(Y,nlag,sum_flag,add_constant,ndraws,burn_in)
% VARDAS_DIFF(Y,nlag,sum_flag,add_constant,ndraws,burn_in)
% 
% 
% Written by Hang Qian, Iowa State University
% Contact me:  matlabist@gmail.com


clear all
H_figure1 = figure('color',[0.1,0.6,0.8]);
set(H_figure1,'position',[200 200 700 500]);

H_welcome = uicontrol(H_figure1,'style','text');
set(H_welcome,'position',[100 200 500 250]);
set(H_welcome,'string',{'Welcome to Bayesian VAR with Varied Frequency Data';'Version 1.0';'Writen by Hang Qian';'Iowa State University';' ';...
     'Follow These Simple Steps        '; '1. Load EXCEL Data             '; '2. Specify Regressors             '; '3. Watch and Have Fun          '});
set(H_welcome,'fontsize',12);

H_start = uicontrol(H_figure1,'style','pushbutton');
set(H_start,'position',[500 50 100 60]);
set(H_start,'string','NEXT');
set(H_start,'fontsize',15);
set(H_start,'callback','set(H_figure1,''visible'',''off'');set(H_figure2,''visible'',''on'');');


H_exit = uicontrol(H_figure1,'style','pushbutton');
set(H_exit,'position',[100 50 100 60]);
set(H_exit,'string','EXIT');
set(H_exit,'fontsize',15);
set(H_exit,'callback','delete(H_figure1);return');


H_figure2 = figure('color',[0.1,0.6,0.8]);
set(H_figure2,'position',[200 200 700 500]);
set(H_figure2,'visible','off');

H_welcome = uicontrol(H_figure2,'style','text');
set(H_welcome,'position',[100 200 500 255]);
set(H_welcome,'string',{'STEP 1: Load EXCEL data';' ';'Save your data in an EXCEL file';'Each variable takes one column. First row is variable names';...
    ' ';'Example:';'GDP inc  tax';'9.2  7.8  8.2';'8.8  7.9  8.5';'8.3  8.4  8.0';'9.9  9.8  7.6';...
    '';'Please enter the EXCEL file name or select a file'});
set(H_welcome,'fontsize',12);
set(H_welcome,'HorizontalAlignment','left');

file_name = 'SampleVARData.xls';
H_filename = uicontrol(H_figure2,'style','edit');
set(H_filename,'position',[100 140 400 40]);
set(H_filename,'backgroundcolor','white');
set(H_filename,'string',file_name);
set(H_filename,'HorizontalAlignment','Left');
set(H_filename,'fontsize',12);

H_selectfile = uicontrol(H_figure2,'style','pushbutton');
set(H_selectfile,'position',[550 140 50 40]);
set(H_selectfile,'string','...');
set(H_selectfile,'fontsize',18);
set(H_selectfile,'callback','[name,path]=uigetfile({''*.xls;*.xlsx;*.csv''});if name~=0;set(H_filename,''string'',[path,name]);end;');

H_next_step = uicontrol(H_figure2,'style','pushbutton');
set(H_next_step,'position',[500 50 100 60]);
set(H_next_step,'string','NEXT');
set(H_next_step,'fontsize',15);
set(H_next_step,'callback','file_name = get(H_filename,''string'');set(H_figure2,''visible'',''off'');set(H_figure3,''visible'',''on'');');

H_previous_step = uicontrol(H_figure2,'style','pushbutton');
set(H_previous_step,'position',[100 50 100 60]);
set(H_previous_step,'string','BACK');
set(H_previous_step,'fontsize',15);
set(H_previous_step,'callback',';set(H_figure2,''visible'',''off'');set(H_figure1,''visible'',''on'');');


H_figure3 = figure('color',[0.1,0.6,0.8]);
set(H_figure3,'position',[200 200 700 500]);
set(H_figure3,'visible','off');

H_welcome = uicontrol(H_figure3,'style','text');
set(H_welcome,'position',[100 420 500 50]);
set(H_welcome,'string',{'STEP 2. Specify your regressors';...
    'Variables names are those in your EXCEL data heading';})
set(H_welcome,'fontsize',12);
set(H_welcome,'HorizontalAlignment','left');

H_x_text = uicontrol(H_figure3,'style','text');
set(H_x_text,'position',[100 390 200 25]);
set(H_x_text,'string','Regressors in VAR');
set(H_x_text,'fontsize',12);

X_str = [];
H_x = uicontrol(H_figure3,'style','edit');
set(H_x,'position',[350 390 200 25]);
set(H_x,'string','');
set(H_x,'fontsize',12);
set(H_x,'HorizontalAlignment','Left');
set(H_x,'backgroundcolor','white');

H_nlag_text = uicontrol(H_figure3,'style','text');
set(H_nlag_text,'position',[100 350 200 20]);
set(H_nlag_text,'string','Number of Lags');
set(H_nlag_text,'fontsize',12);

nlag_VAR = 2;
H_nlag = uicontrol(H_figure3,'style','edit');
set(H_nlag,'position',[350 350 200 25]);
set(H_nlag,'string',num2str(nlag_VAR));
set(H_nlag,'fontsize',12);
set(H_nlag,'backgroundcolor','white');

add_constant = 0;
H_constant = uicontrol(H_figure3,'style','checkbox');
set(H_constant,'position',[100 300 450 20]);
set(H_constant,'string','  Add a constant (intercept) term in the VAR');
set(H_constant,'fontsize',11);
set(H_constant,'callback','add_constant = get(H_constant,''Value'');');

sum_flag = 1;
H_sum = uicontrol(H_figure3,'style','popupmenu');
set(H_sum,'position',[100 250 450 30]);
set(H_sum,'string','Disaggregated data average to aggregated data|Disaggregated data sum up to aggregated data');
set(H_sum,'fontsize',12);
set(H_sum,'callback','sum_flag = get(H_sum,''value'')-1;');

model_flag = 1;
H_model = uicontrol(H_figure3,'style','popupmenu');
set(H_model,'position',[100 200 450 30]);
set(H_model,'string','Choose a method|Some series of low frequency, Some of high frequency (Fast)|Series change frequency once from low to high (Fast)|General aggregation, block sampler (Slow)|General aggregation, giant MVN (Very Slow)');
set(H_model,'fontsize',12);
set(H_model,'callback','model_flag = get(H_model,''value'')-1;');

H_ndraws_text = uicontrol(H_figure3,'style','text');
set(H_ndraws_text,'position',[100 150 200 20]);
set(H_ndraws_text,'string','Number of MCMC draws');
set(H_ndraws_text,'fontsize',12);

ndraws = 5000;
H_ndraws = uicontrol(H_figure3,'style','edit');
set(H_ndraws,'position',[350 150 100 20]);
set(H_ndraws,'string',num2str(ndraws));
set(H_ndraws,'fontsize',12);
set(H_ndraws,'backgroundcolor','white');

H_burn_in_text = uicontrol(H_figure3,'style','text');
set(H_burn_in_text,'position',[100 120 200 20]);
set(H_burn_in_text,'string','Number of burn-in draws');
set(H_burn_in_text,'fontsize',12);

burn_in = 2000;
H_burn_in = uicontrol(H_figure3,'style','edit');
set(H_burn_in,'position',[350 120 100 20]);
set(H_burn_in,'string',num2str(burn_in));
set(H_burn_in,'fontsize',12);
set(H_burn_in,'backgroundcolor','white');

H_next_step = uicontrol(H_figure3,'style','pushbutton');
set(H_next_step,'position',[500 50 100 60]);
set(H_next_step,'string','DONE');
set(H_next_step,'fontsize',15);
set(H_next_step,'callback','X_str = get(H_x,''string'');nlag_VAR = str2num(get(H_nlag,''string''));ndraws = str2num(get(H_ndraws,''string''));burn_in = str2num(get(H_burn_in,''string''));close(H_figure3);DATA_PROCESS;');

H_previous_step = uicontrol(H_figure3,'style','pushbutton');
set(H_previous_step,'position',[100 50 100 60]);
set(H_previous_step,'string','BACK');
set(H_previous_step,'fontsize',15);
set(H_previous_step,'callback','set(H_figure3,''visible'',''off'');set(H_figure2,''visible'',''on'')');


